=======
Authors
=======

| Jonas Eschle <Jonas.Eschle@cern.ch>
| Albert Puig <albert@protonmail.com>
| Rafael Silva Coutinho <rsilvaco@cern.ch>
| Nicola Serra <nserra@cern.ch>
| Matthieu Marinangeli <matthieu.marinangeli@cern.ch>

Development Lead
----------------

* zfit <zfit@physik.uzh.ch>

Contributors
------------
| Chris Burr <christopher.burr@cern.ch>
| Martina Ferrillo <martina.ferrillo@cern.ch>
| Abhijit Mathad <amathad@cern.ch>
| Oliver Lantwin <oliver.lantwin@cern.ch>
| Johannes Lade <johannes.lade@yahoo.com>
